@@ -95,3 +95,9 @@ with TqdmUpTo(unit='B', unit_scale=True, unit_divisor=1024, miniters=1,
               desc=eg_file) as t:  # all optional kwargs
     urllib.urlretrieve(eg_link, filename=eg_out, reporthook=t.update_to,
                        data=None)
+
+# Even simpler progress by wrapping the output file's `write()`
+with tqdm.wrapattr(open(eg_out, "wb"), "write",
+                   miniters=1, desc=eg_file) as fout:
+    for chunk in urllib.urlopen(eg_link):
+        fout.write(chunk)
